@@ -1,4 +1,4 @@
-const baseConfig = require('cdk-build-tools/config/eslintrc');
+const baseConfig = require('@aws-cdk/cdk-build-tools/config/eslintrc');
 baseConfig.parserOptions.project = __dirname + '/tsconfig.json';
 module.exports = {
   ...baseConfig,
