@@ -598,7 +598,9 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param stack: the CDK Stack to run assertions on.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Annotations.from_stack)
+            def stub(stack: aws_cdk.core.Stack) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast("Annotations", jsii.sinvoke(cls, "fromStack", [stack]))
 
@@ -614,7 +616,9 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param message: the error message as should be expected. This should be a string or Matcher object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Annotations.find_error)
+            def stub(construct_path: builtins.str, message: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
             check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(typing.List[aws_cdk.cx_api.SynthesisMessage], jsii.invoke(self, "findError", [construct_path, message]))
@@ -631,7 +635,9 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param message: the info message as should be expected. This should be a string or Matcher object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Annotations.find_info)
+            def stub(construct_path: builtins.str, message: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
             check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(typing.List[aws_cdk.cx_api.SynthesisMessage], jsii.invoke(self, "findInfo", [construct_path, message]))
@@ -648,7 +654,9 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param message: the warning message as should be expected. This should be a string or Matcher object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Annotations.find_warning)
+            def stub(construct_path: builtins.str, message: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
             check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(typing.List[aws_cdk.cx_api.SynthesisMessage], jsii.invoke(self, "findWarning", [construct_path, message]))
@@ -661,7 +669,9 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param message: the error message as should be expected. This should be a string or Matcher object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Annotations.has_error)
+            def stub(construct_path: builtins.str, message: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
             check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "hasError", [construct_path, message]))
@@ -674,7 +684,9 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param message: the info message as should be expected. This should be a string or Matcher object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Annotations.has_info)
+            def stub(construct_path: builtins.str, message: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
             check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "hasInfo", [construct_path, message]))
@@ -687,7 +699,9 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param message: the error message as should be expected. This should be a string or Matcher object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Annotations.has_no_error)
+            def stub(construct_path: builtins.str, message: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
             check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "hasNoError", [construct_path, message]))
@@ -700,7 +714,9 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param message: the info message as should be expected. This should be a string or Matcher object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Annotations.has_no_info)
+            def stub(construct_path: builtins.str, message: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
             check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "hasNoInfo", [construct_path, message]))
@@ -713,7 +729,9 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param message: the warning message as should be expected. This should be a string or Matcher object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Annotations.has_no_warning)
+            def stub(construct_path: builtins.str, message: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
             check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "hasNoWarning", [construct_path, message]))
@@ -726,7 +744,9 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param message: the warning message as should be expected. This should be a string or Matcher object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Annotations.has_warning)
+            def stub(construct_path: builtins.str, message: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
             check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "hasWarning", [construct_path, message]))
@@ -760,7 +780,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
         :param pattern: the pattern to match.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Match.array_equals)
+            def stub(pattern: typing.Sequence[typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "arrayEquals", [pattern]))
 
@@ -774,7 +796,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
         :param pattern: the pattern to match.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Match.array_with)
+            def stub(pattern: typing.Sequence[typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "arrayWith", [pattern]))
 
@@ -786,7 +810,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
         :param pattern: the pattern to match.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Match.exact)
+            def stub(pattern: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "exact", [pattern]))
 
@@ -798,7 +824,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
         :param pattern: the pattern to NOT match.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Match.not_)
+            def stub(pattern: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "not", [pattern]))
 
@@ -815,7 +843,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
         :param pattern: the pattern to match.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Match.object_equals)
+            def stub(pattern: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "objectEquals", [pattern]))
 
@@ -832,7 +862,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
         :param pattern: the pattern to match.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Match.object_like)
+            def stub(pattern: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "objectLike", [pattern]))
 
@@ -844,7 +876,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
         :param pattern: the pattern to match after parsing the encoded JSON.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Match.serialized_json)
+            def stub(pattern: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "serializedJson", [pattern]))
 
@@ -856,7 +890,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
         :param pattern: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Match.string_like_regexp)
+            def stub(pattern: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "stringLikeRegexp", [pattern]))
 
@@ -897,7 +933,9 @@ class MatchCapture:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MatchCapture.__init__)
+            def stub(*, capture: "Capture", value: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument capture", value=capture, expected_type=type_hints["capture"])
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -967,7 +1005,14 @@ class MatchFailure:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MatchFailure.__init__)
+            def stub(
+                *,
+                matcher: "Matcher",
+                message: builtins.str,
+                path: typing.Sequence[builtins.str],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument matcher", value=matcher, expected_type=type_hints["matcher"])
             check_type(argname="argument message", value=message, expected_type=type_hints["message"])
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
@@ -1036,7 +1081,9 @@ class MatchResult(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.MatchR
         :param target: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MatchResult.__init__)
+            def stub(target: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         jsii.create(self.__class__, self, [target])
 
@@ -1048,7 +1095,9 @@ class MatchResult(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.MatchR
         :param inner: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MatchResult.compose)
+            def stub(id: builtins.str, inner: "MatchResult") -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument inner", value=inner, expected_type=type_hints["inner"])
         return typing.cast("MatchResult", jsii.invoke(self, "compose", [id, inner]))
@@ -1087,7 +1136,13 @@ class MatchResult(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.MatchR
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MatchResult.push)
+            def stub(
+                matcher: "Matcher",
+                path: typing.Sequence[builtins.str],
+                message: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument matcher", value=matcher, expected_type=type_hints["matcher"])
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
             check_type(argname="argument message", value=message, expected_type=type_hints["message"])
@@ -1184,7 +1239,9 @@ class Matcher(
         :param x: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Matcher.is_matcher)
+            def stub(x: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument x", value=x, expected_type=type_hints["x"])
         return typing.cast(builtins.bool, jsii.sinvoke(cls, "isMatcher", [x]))
 
@@ -1226,7 +1283,9 @@ class _MatcherProxy(Matcher):
         :return: the list of match failures. An empty array denotes a successful match.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Matcher.test)
+            def stub(actual: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument actual", value=actual, expected_type=type_hints["actual"])
         return typing.cast(MatchResult, jsii.invoke(self, "test", [actual]))
 
@@ -1272,7 +1331,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param template: the CloudFormation template formatted as a nested set of records.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.from_json)
+            def stub(template: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument template", value=template, expected_type=type_hints["template"])
         return typing.cast("Template", jsii.sinvoke(cls, "fromJSON", [template]))
 
@@ -1284,7 +1345,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param stack: the CDK Stack to run assertions on.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.from_stack)
+            def stub(stack: aws_cdk.core.Stack) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast("Template", jsii.sinvoke(cls, "fromStack", [stack]))
 
@@ -1296,7 +1359,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param template: the CloudFormation template in.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.from_string)
+            def stub(template: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument template", value=template, expected_type=type_hints["template"])
         return typing.cast("Template", jsii.sinvoke(cls, "fromString", [template]))
 
@@ -1312,7 +1377,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param props: by default, matches all Conditions in the template. When a literal object is provided, performs a partial match via ``Match.objectLike()``. Use the ``Match`` APIs to configure a different behaviour.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.find_conditions)
+            def stub(logical_id: builtins.str, props: typing.Any = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findConditions", [logical_id, props]))
@@ -1329,7 +1396,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param props: by default, matches all Mappings in the template. When a literal object is provided, performs a partial match via ``Match.objectLike()``. Use the ``Match`` APIs to configure a different behaviour.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.find_mappings)
+            def stub(logical_id: builtins.str, props: typing.Any = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findMappings", [logical_id, props]))
@@ -1346,7 +1415,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param props: by default, matches all Outputs in the template. When a literal object is provided, performs a partial match via ``Match.objectLike()``. Use the ``Match`` APIs to configure a different behaviour.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.find_outputs)
+            def stub(logical_id: builtins.str, props: typing.Any = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findOutputs", [logical_id, props]))
@@ -1363,7 +1434,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param props: by default, matches all Parameters in the template. When a literal object is provided, performs a partial match via ``Match.objectLike()``. Use the ``Match`` APIs to configure a different behaviour.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.find_parameters)
+            def stub(logical_id: builtins.str, props: typing.Any = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findParameters", [logical_id, props]))
@@ -1380,7 +1453,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param props: by default, matches all resources with the given type. When a literal is provided, performs a partial match via ``Match.objectLike()``. Use the ``Match`` APIs to configure a different behaviour.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.find_resources)
+            def stub(type: builtins.str, props: typing.Any = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findResources", [type, props]))
@@ -1396,7 +1471,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param props: the output as should be expected in the template.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.has_condition)
+            def stub(logical_id: builtins.str, props: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(None, jsii.invoke(self, "hasCondition", [logical_id, props]))
@@ -1412,7 +1489,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param props: the output as should be expected in the template.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.has_mapping)
+            def stub(logical_id: builtins.str, props: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(None, jsii.invoke(self, "hasMapping", [logical_id, props]))
@@ -1428,7 +1507,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param props: the output as should be expected in the template.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.has_output)
+            def stub(logical_id: builtins.str, props: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(None, jsii.invoke(self, "hasOutput", [logical_id, props]))
@@ -1444,7 +1525,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param props: the parameter as should be expected in the template.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.has_parameter)
+            def stub(logical_id: builtins.str, props: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(None, jsii.invoke(self, "hasParameter", [logical_id, props]))
@@ -1460,7 +1543,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param props: the entire defintion of the resource as should be expected in the template.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.has_resource)
+            def stub(type: builtins.str, props: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(None, jsii.invoke(self, "hasResource", [type, props]))
@@ -1476,7 +1561,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param props: the 'Properties' section of the resource as should be expected in the template.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.has_resource_properties)
+            def stub(type: builtins.str, props: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(None, jsii.invoke(self, "hasResourceProperties", [type, props]))
@@ -1489,7 +1576,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param count: number of expected instances.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.resource_count_is)
+            def stub(type: builtins.str, count: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
         return typing.cast(None, jsii.invoke(self, "resourceCountIs", [type, count]))
@@ -1501,7 +1590,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param expected: the expected CloudFormation template as key-value pairs.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Template.template_matches)
+            def stub(expected: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument expected", value=expected, expected_type=type_hints["expected"])
         return typing.cast(None, jsii.invoke(self, "templateMatches", [expected]))
 
@@ -1559,7 +1650,9 @@ class Capture(
         :param pattern: a nested pattern or Matcher. If a nested pattern is provided ``objectLike()`` matching is applied.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Capture.__init__)
+            def stub(pattern: typing.Any = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         jsii.create(self.__class__, self, [pattern])
 
@@ -1621,7 +1714,9 @@ class Capture(
         :param actual: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Capture.test)
+            def stub(actual: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument actual", value=actual, expected_type=type_hints["actual"])
         return typing.cast(MatchResult, jsii.invoke(self, "test", [actual]))
 
